###################################################################
# Replication of Lehrer/Lin (FIGURE 1 ONLY)                       #
# " Everything To Everyone? Not When You Are Internally Divivded" #
# Created by Roni Lehrer                                          #
# Last changes made on: 11 October 2018                           #
#                                                                 #
# see end of script for information on R and packages versions    #
###################################################################

rm(list=ls())
library(agrmt)
library(ggplot2)
set.seed(9212)

#draw 1000 time from normal with mean=5 and sd=1.99, then truncate to [0; 10].
a <- trunc(rnorm(1000, 5, 1.99))
a <- ifelse(a<0, 0, a)
a <- ifelse(a>10, 10, a)

#draw 500 time from normal with mean=3.6 and sd=1.05, then truncate to [0; 10].
b <- trunc(rnorm(500, 3.6, 1.05))
b <- ifelse(b<0, 0, b)
b <- ifelse(b>10, 10, b)

#draw 500 time from normal with mean=3.6 and sd=1.05, then truncate to [0; 10].
c <- trunc(rnorm(500, 6.4, 1.05))
c <- ifelse(c<0, 0, c)
c <- ifelse(c>10, 10, c)

#combine b and c to be one population
over <- c(b,c)

#compute agreement scores
c(round(agreement(as.vector(table(a))),2), round(agreement(as.vector(table(over))),2))

#create dataset of frequency per position per group type
ta <- table(a)
tb <- table(b)
tc <- table(c)
dat <- data.frame(position=rep(as.numeric(names(ta)),3),
                  plot=factor(c(rep(1, 11), rep(2, 22)), labels=c('United Party', 'Divided Party')),
                  type=c(rep("Cohesive", 11),
                         rep("Div1", 11),
                         rep("Div2", 11)),
                  freq=c(as.vector(ta),
                      c(as.vector(tb), 0,0,0,0),
                      c(0, 0, as.vector(tc), 0)
                       )
                  )

# create Figure 1
theory.plot <- ggplot(dat, aes(x=position, y=freq, fill=type)) +
              geom_bar(stat="identity") +
              facet_grid(.~plot) +
              scale_fill_manual(values=c("gray50", "gray50", "gray77"), guide=FALSE) +
              scale_x_discrete("Policy Position", 0:10, as.character(0:10), 0:10) +
              labs(list(x="", y="Frequency")) + 
              theme_bw() + 
              theme(strip.text.x = element_text(size = 13, colour = "black", face="bold")) +
              theme(axis.text.x = element_text(size=10, colour = "grey20"),
                    axis.text.y = element_text(size=10, hjust=0, colour = "grey20"),
                    axis.title.y= element_text(size=14, face="bold"),
                    axis.title.x= element_text(size=14, face="bold"),) 
theory.plot



#########################################################
## sessionInfo() on the machine this R-script was with: #
#########################################################
## R version 3.5.1 (2018-07-02)
## Platform: x86_64-w64-mingw32/x64 (64-bit)
## Running under: Windows 7 x64 (build 7601) Service Pack 1

## Matrix products: default

## locale:
## [1] LC_COLLATE=German_Germany.1252  LC_CTYPE=German_Germany.1252   
## [3] LC_MONETARY=German_Germany.1252 LC_NUMERIC=C                   
## [5] LC_TIME=German_Germany.1252    

## attached base packages:
## [1] stats     graphics  grDevices utils     datasets  methods   base     

## other attached packages:
## [1] ggplot2_3.0.0 agrmt_1.40.4 

## loaded via a namespace (and not attached):
##  [1] Rcpp_0.12.19     bindr_0.1.1      magrittr_1.5     tidyselect_0.2.4
##  [5] munsell_0.5.0    colorspace_1.3-2 R6_2.3.0         rlang_0.2.2     
##  [9] stringr_1.3.1    plyr_1.8.4       dplyr_0.7.6      tools_3.5.1     
## [13] grid_3.5.1       gtable_0.2.0     withr_2.1.2      lazyeval_0.2.1  
## [17] assertthat_0.2.0 tibble_1.4.2     crayon_1.3.4     bindrcpp_0.2.2  
## [21] purrr_0.2.5      reshape2_1.4.3   glue_1.3.0       labeling_0.3    
## [25] stringi_1.2.4    compiler_3.5.1   pillar_1.3.0     scales_1.0.0    
## [29] pkgconfig_2.0.2 
