﻿*#================================================================#
*# Replication of Lehrer/Lin									  #
*# "Everything To Everyone? Not When You Are Internally Divivded" #
*#																  #
*# Created by Roni Lehrer & Nick Lin							  #
*# Last changes made on: 15 October 2018                          #
*#================================================================#

*#=======================================================================================================#
*# This replication file requires data from Waves 1, 2, 7, and 8 of the German Internet Panel.           #
*# They are stored at the Gesis Data Archive as:                                                         #
*#                                                                                                       #
*# #Wave 1:#                                                                                             #
*# Blom, Annelies G.; Bossert, Dayana; Funke, Frederik; Gebhard, Franziska; Holthausen, Annette;         #
*# Krieger, Ulrich; SFB 884 ´Political Economy of Reforms´ Universität Mannheim (2016):                  #
*# German Internet Panel, Wave 1 - Core Study (September 2012). GESIS Data Archive, Cologne.             #
*# ZA5866 Data file Version 2.0.0, doi:10.4232/1.12607                                                   #
*#                                                                                                       #
*# Internet: http://dx.doi.org/10.4232/1.12607                                                           #
*# Gesis Study Number : ZA5866                                                                           #
*#                                                                                                       #
*# #Wave 2:#                                                                                             #
*# Blom, Annelies G.; Bossert, Dayana; Funke, Frederik; Gebhard, Franziska; Holthausen, Annette;         #
*# Krieger, Ulrich; SFB 884 ´Political Economy of Reforms´ Universität Mannheim (2016):                  #
*# German Internet Panel, Wave 2 (November 2012). GESIS Data Archive, Cologne.                           #
*# ZA5867 Data file Version 2.0.0, doi:10.4232/1.12608                                                   #
*#                                                                                                       #
*# Internet: http://dx.doi.org/10.4232/1.12608                                                           #
*# Gesis Study Number : ZA5867                                                                           #
*#                                                                                                       #
*# #Wave 7:#                                                                                             #
*# Blom, Annelies G.; Bossert, Dayana; Gebhard, Franziska; Funke, Frederik; Holthausen, Annette;         #
*# Krieger, Ulrich; SFB 884 ´Political Economy of Reforms´ Universität Mannheim (2016):                  #
*# German Internet Panel, Wave 7 - Core Study (September 2013). GESIS Data Archive, Cologne.             #
*# ZA5872 Data file Version 2.0.0, doi:10.4232/1.12613                                                   #
*#                                                                                                       #
*# Internet: http://dx.doi.org/10.4232/1.12613                                                           #
*# Gesis Study Number : ZA5872                                                                           #
*#                                                                                                       #
*# #Wave 8:#                                                                                             #
*# Blom, Annelies G.; Bossert, Dayana; Funke, Frederik; Gebhard, Franziska; Holthausen, Annette;         #
*# Krieger, Ulrich; SFB 884 ´Political Economy of Reforms´ Universität Mannheim (2016):                  #
*# German Internet Panel, Wave 8 (November 2013). GESIS Data Archive, Cologne.                           #
*# ZA5873 Data file Version 2.0.0, doi:10.4232/1.12614                                                   #
*#                                                                                                       #
*# Internet: http://dx.doi.org/10.4232/1.12614                                                           #
*# Gesis Study Number : ZA5873                                                                           #
*#=======================================================================================================#

*#=======================================================================================================#
*# This replication file requires an additional adofile called "agrm".                                   #
*# You can download it at http://fmwww.bc.edu/RePEc/bocode/a/agrm.ado (accessed 11 October 2018)         #
*# or by typing "net install agrm".                                                                      #
*#=======================================================================================================#

set matsize 2000
set seed 65484
set scheme s1mono


*##=================##
*## Generating Data ##
*##=================##
version 15.1
use ZA5866_v2-0-0, clear
rename state state1
rename educ_school_12 educ1
sort id_g

merge 1:1 id_g using ZA5872_v2-0-0
drop _merge
rename state state7
rename educ_school_13 educ7

merge 1:1 id_g using ZA5867_v2-0-0
drop _merge 

merge 1:1 id_g using ZA5873_v2-0-0
drop _merge 

recode educ1 (-90=.) (7=.)
recode educ7 (-90=.) (7=.)

*rename unity questions and delete missings
rename CE08113 unity_CDU8
rename CE08114 unity_SPD8
rename CE08115 unity_FDP8
rename CE08116 unity_GR8
rename CE08117 unity_LIN8

rename CE02057 unity_CDU2
rename CE02058 unity_SPD2
rename CE02059 unity_FDP2
rename CE02060 unity_GR2
rename CE02061 unity_LIN2

label define unity 1 "incohesive" 11 "cohesive"
foreach x of varlist unity* {
 replace `x'  = . if `x' <0
 *replace `x' = `x' -6
 label values `x' unity
}

*rename party ID questions and delete missings
rename AA01042 partisan1
recode partisan1 (-90=.) (2=0)
replace partisan1 = AA01043 if partisan1==1
recode partisan1 (-98=.) (1=3) (2=4) (3=5) (4=6) (5=7) (6=8) (7=10)
label define partisan 0 "none" 3 "CDU/CSU" 4 "SPD" 5 "FDP" 6 "Grüne" 7 "Linke" 8 "NPD" 9 "Piraten" 10 "andere" 11 "AfD"
label values partisan1 partisan

rename AA07042 partisan7
recode partisan7 (-90=.) (2=0)
replace partisan7 = AA07043 if partisan7==1
recode partisan7 (-98=.) (1=3) (2=4) (3=5) (4=6) (5=7) (6=8) (7=10)
label values partisan7 partisan

*rename vote intention questions and delete missings
rename CE08111 sonntag8
rename CE02008 sonntag2

label define sonntag 1 "don't know" 2 "wouldn't vote" 3 "CDU/CSU" 4 "SPD" 5 "FDP" 6 "Grüne" 7 "Linke" 8 "NPD" 9 "Piraten" 10 "other" 11 "AfD"
recode sonntag2 (-99=1)(-98=.) (1=2) (2=.)
label values sonntag2 sonntag

recode sonntag8 (-99=1)(-90=.) (1=3) (2=4) (3=5) (4=6) (5=7) (6=8) (7=9) (8=11) (9=10) (10=.) (11=2)
label values sonntag8 sonntag

*rename intention recall questions and delete missings
rename AA01038 last_vote1
label define last_vote 1 "don't know" 2 "didn't vote" 3 "CDU/CSU" 4 "SPD" 5 "FDP" 6 "Grüne" 7 "Linke" 8 "NPD" 9 "Piraten" 10 "other" 11 "AfD"
recode last_vote1 (-99=1) (-98=.) (2=.) (1=2)
label values last_vote1 last_vote

rename CE08110 last_vote7
recode last_vote7 (-99=1) (-98/-90=.) (10=.) (11=2) (1=3) (2=4) (3=5) (4=6) (5=7) (6=8) (7=9) (8=11) (9=10)
label values last_vote7 last_vote

*rename self-placement questions and delete missings
rename AA07040a self7a //Asked before parties
rename AA07040b self7b //Asked after parties
rename AA01040a self1a //Asked before parties
rename AA01040b self1b //Asked after parties

label define lrscale 1 "left" 11 "right"
foreach x of varlist self* {
 replace `x' = . if `x'<0
 label values `x' lrscale
}

*rename party placement questions and delete missings
rename AA07041a1 vtr_plcmntCDU7a
rename AA07041a3 vtr_plcmntSPD7a
rename AA07041a4 vtr_plcmntFDP7a
rename AA07041a5 vtr_plcmntGR7a
rename AA07041a6 vtr_plcmntLIN7a
rename AA07041b1 vtr_plcmntCDU7b
rename AA07041b3 vtr_plcmntSPD7b
rename AA07041b4 vtr_plcmntFDP7b
rename AA07041b5 vtr_plcmntGR7b
rename AA07041b6 vtr_plcmntLIN7b

rename AA01041a1 vtr_plcmntCDU1a
rename AA01041a3 vtr_plcmntSPD1a
rename AA01041a4 vtr_plcmntFDP1a
rename AA01041a5 vtr_plcmntGR1a
rename AA01041a6 vtr_plcmntLIN1a
rename AA01041b1 vtr_plcmntCDU1b
rename AA01041b3 vtr_plcmntSPD1b
rename AA01041b4 vtr_plcmntFDP1b
rename AA01041b5 vtr_plcmntGR1b
rename AA01041b6 vtr_plcmntLIN1b

foreach x of varlist vtr_plcmnt* {
 replace `x' = . if `x'<0
 label values `x' lrscale
}

*drop variables not needed for further analysis
keep id_g unity*2 unity*8 self1a self1b self7a self7b vtr_plcmnt*1a vtr_plcmnt*1b vtr_plcmnt*7a vtr_plcmnt*7b sonntag2 sonntag8 state1 state7 educ* partisan* last_vote*

*in wave 1, placement questions are saved in different variables depending on when in the questionnaire it was asked. Lump together.
foreach x in self1 self7 vtr_plcmntCDU1 vtr_plcmntSPD1 vtr_plcmntFDP1 vtr_plcmntGR1 vtr_plcmntLIN1 ///
                         vtr_plcmntCDU7 vtr_plcmntSPD7 vtr_plcmntFDP7 vtr_plcmntGR7 vtr_plcmntLIN7 {
 gen `x' = `x'a
 replace `x' = `x'b if `x'==.
 drop `x'a `x'b
}

gen distCDU1 = abs(self1-vtr_plcmntCDU1)
gen distSPD1 = abs(self1-vtr_plcmntSPD1)
gen distFDP1 = abs(self1-vtr_plcmntFDP1)
gen distGR1 =  abs(self1-vtr_plcmntGR1)
gen distLIN1 = abs(self1-vtr_plcmntLIN1)

gen distCDU7 = abs(self7-vtr_plcmntCDU7)
gen distSPD7 = abs(self7-vtr_plcmntSPD7)
gen distFDP7 = abs(self7-vtr_plcmntFDP7)
gen distGR7 =  abs(self7-vtr_plcmntGR7)
gen distLIN7 = abs(self7-vtr_plcmntLIN7)

*get mean placements as actual party positions
egen mean_vtr_plcmntCDU1 = mean(vtr_plcmntCDU1)
egen mean_vtr_plcmntSPD1 = mean(vtr_plcmntSPD1)
egen mean_vtr_plcmntFDP1 = mean(vtr_plcmntFDP1)
egen mean_vtr_plcmntGR1  = mean(vtr_plcmntGR1)
egen mean_vtr_plcmntLIN1 = mean(vtr_plcmntLIN1)

egen mean_vtr_plcmntCDU7 = mean(vtr_plcmntCDU7)
egen mean_vtr_plcmntSPD7 = mean(vtr_plcmntSPD7)
egen mean_vtr_plcmntFDP7 = mean(vtr_plcmntFDP7)
egen mean_vtr_plcmntGR7  = mean(vtr_plcmntGR7)
egen mean_vtr_plcmntLIN7 = mean(vtr_plcmntLIN7)

*van Eijk (2001) disagreement measure
agrm vtr_plcmntCDU1, gen(a_vtr_plcmntCDU1) cat(11)
agrm vtr_plcmntSPD1, gen(a_vtr_plcmntSPD1) cat(11)
agrm vtr_plcmntFDP1, gen(a_vtr_plcmntFDP1) cat(11)
agrm vtr_plcmntGR1 , gen(a_vtr_plcmntGR1 ) cat(11)
agrm vtr_plcmntLIN1, gen(a_vtr_plcmntLIN1) cat(11)

agrm vtr_plcmntCDU7, gen(a_vtr_plcmntCDU7) cat(11)
agrm vtr_plcmntSPD7, gen(a_vtr_plcmntSPD7) cat(11)
agrm vtr_plcmntFDP7, gen(a_vtr_plcmntFDP7) cat(11)
agrm vtr_plcmntGR7 , gen(a_vtr_plcmntGR7 ) cat(11)
agrm vtr_plcmntLIN7, gen(a_vtr_plcmntLIN7) cat(11)

*create dataset with one observation per respondent-party-wave
expand 5
sort id_g
bysort id_g: gen party = _n
replace party = party+2 //to match vote intention question
label values party sonntag

*assign each party given respondents perceived distance
gen dist1 = .
replace dist1 = distCDU1 if party==3
replace dist1 = distSPD1 if party==4
replace dist1 = distFDP1 if party==5
replace dist1 = distGR1 if party==6
replace dist1 = distLIN1 if party==7

gen dist7 = .
replace dist7 = distCDU7 if party==3
replace dist7 = distSPD7 if party==4
replace dist7 = distFDP7 if party==5
replace dist7 = distGR7 if party==6
replace dist7 = distLIN7 if party==7

*assign each party given respondents actual distance
gen act_dist_CDU1 = abs(mean_vtr_plcmntCDU1-self1)
gen act_dist_SPD1 = abs(mean_vtr_plcmntSPD1-self1)
gen act_dist_FDP1 = abs(mean_vtr_plcmntFDP1-self1)
gen act_dist_GR1 =  abs(mean_vtr_plcmntGR1 -self1)
gen act_dist_LIN1 = abs(mean_vtr_plcmntLIN1-self1)

gen act_dist_CDU7 = abs(mean_vtr_plcmntCDU7-self7)
gen act_dist_SPD7 = abs(mean_vtr_plcmntSPD7-self7)
gen act_dist_FDP7 = abs(mean_vtr_plcmntFDP7-self7)
gen act_dist_GR7 =  abs(mean_vtr_plcmntGR7 -self7)
gen act_dist_LIN7 = abs(mean_vtr_plcmntLIN7-self7)

gen act_dist1 = .
replace act_dist1 = act_dist_CDU1 if party==3
replace act_dist1 = act_dist_SPD1 if party==4
replace act_dist1 = act_dist_FDP1 if party==5
replace act_dist1 = act_dist_GR1 if party==6
replace act_dist1 = act_dist_LIN1 if party==7

gen act_dist7 = .
replace act_dist7 = act_dist_CDU7 if party==3
replace act_dist7 = act_dist_SPD7 if party==4
replace act_dist7 = act_dist_FDP7 if party==5
replace act_dist7 = act_dist_GR7 if party==6
replace act_dist7 = act_dist_LIN7 if party==7
drop act_dist_*

*assign each party its disagreement score
gen disagreement1 = a_vtr_plcmntCDU1
replace disagreement1 = a_vtr_plcmntSPD1 if party==4
replace disagreement1 = a_vtr_plcmntFDP1 if party==5
replace disagreement1 = a_vtr_plcmntGR1 if party==6
replace disagreement1 = a_vtr_plcmntLIN1 if party==7
replace disagreement1 = (disagreement1*-.5)+.5 //recode as in Somer-Topcu 2015

gen disagreement7 = a_vtr_plcmntCDU7
replace disagreement7 = a_vtr_plcmntSPD7 if party==4
replace disagreement7 = a_vtr_plcmntFDP7 if party==5
replace disagreement7 = a_vtr_plcmntGR7 if party==6
replace disagreement7 = a_vtr_plcmntLIN7 if party==7
replace disagreement7 = (disagreement7*-.5)+.5 //recode as in Somer-Topcu 2015

*assign each party given respondents perceived unity
gen unity2 = .
replace unity2 = unity_CDU2 if party==3
replace unity2 = unity_SPD2 if party==4
replace unity2 = unity_FDP2 if party==5
replace unity2 = unity_GR2 if party==6
replace unity2 = unity_LIN2 if party==7
label values unity2 unity

gen unity8 = .
replace unity8 = unity_CDU8 if party==3
replace unity8 = unity_SPD8 if party==4
replace unity8 = unity_FDP8 if party==5
replace unity8 = unity_GR8 if party==6
replace unity8 = unity_LIN8 if party==7
label values unity8 unity

*create a respondent party id across waves
egen id =group(id_g party) 

*rename so that varibale that are treated as from the same wave have same number (for reshaping)
rename unity2 unity1
rename unity8 unity7
rename sonntag2 sonntag1
rename sonntag8 sonntag7

*remove variables no longer needed
keep id id_g act_dist1 act_dist7 dist1 dist7 unity1 unity7 party self1 self7 disagreement* educ* sonntag* partisan* last_vote*
 
*reshape to long dataset
reshape long dist unity act_dist self disagreement educ sonntag partisan last_vote, i(id) j(wave)
gen second_wave = 0
replace second_wave = 1 if wave==7
replace second_wave = . if wave==.

*create dummy for vote_intention of a given party
gen vote_intention = 0
replace vote_intention = 1 if sonntag==party&sonntag!=.
replace vote_intention = . if sonntag==.

*create dummy for partisanship of a given party
gen partisanIndicator = 0
replace partisanIndicator = 1 if partisan==party
replace partisanIndicator = . if partisan==.
drop partisan
rename partisanIndicator partisan
 
 *create dummy for last vote of a given party
gen last_voteIndicator = 0
replace last_voteIndicator = 1 if last_vote==party
replace last_voteIndicator = . if last_vote==.
drop last_vote
rename last_voteIndicator last_vote
 
 *create dummy for single issue party (Die Linke)
gen single_issue=0
replace single_issue=1 if party==7

*create dummy for government parties (CDU and SPD)
gen government=0
replace government=1 if party==3|party==5
 
gen vote_share=.
replace vote_share=33.8 if party==3
replace vote_share=23.0 if party==4
replace vote_share=14.6 if party==5
replace vote_share=11.9 if party==6
replace vote_share=10.7 if party==7

*create more identifiers 
gen party_wave = (party*100)+wave
egen wave_individual = group(wave id_g)

*create dummy for high ambiguity
gen ambiguityDum = .
sum disagreement
replace ambiguityDum = 1 if disagreement >= r(mean)
replace ambiguityDum = 0 if disagreement < r(mean)

*keep only cases that have all data points
reg dist c.act_dist##c.disagreement single_issue government vote_share partisan educ party party_wave unity
keep if e(sample)


*##========================================##
*## Empirical Analysis: Tables and Figures ##
*##========================================##
	
/* Note: 1. Figure 1 was generated using R, please see the R file for the code.
		 2. Estimates for all other figures (Figure 2, 3, A1, A2, and A3) were generated by STATA and then we plot them using ggplot2 in R.
		    In this do-file, we provide codes to generate the same figures in STATA, and the R code is available upon request. 
*/	
	
	*### Table 1 ###*
	sutex dist act_dist ambiguityDum unity single_issue government vote_share partisan educ wave, minmax


	*### Table 2 ###*
	xtmixed dist c.act_dist##i.ambiguityDum##c.unity  || party: || party_wave:  
	est store m1 

	xtmixed dist c.act_dist##i.ambiguityDum##c.unity single_issue government vote_share partisan educ i.wave || party: || party_wave:  
	est store m2

	esttab m1 m2, b(%10.3f) se scalars (N ll) star(+ 0.10 * 0.05 ** 0.01) noomitted /*
		*/ keep(act_dist 1.ambiguityDum unity 1.ambiguityDum#c.act_dist c.act_dist#c.unity 1.ambiguityDum#c.unity 1.ambiguityDum#c.act_dist#c.unity  /*
		*/		single_issue government vote_share partisan educ 7.wave _cons) /*
		*/ coeflabels(act_dist "Actual Distance" 1.ambiguityDum "Ambiguous Party" unity "Perceived Party Unity" 1.ambiguityDum#c.act_dist "Distance * Ambiguity" /*
		*/			  c.act_dist#c.unity "Distance * Unity" 1.ambiguityDum#c.unity "Ambiguity * Unity" 1.ambiguityDum#c.act_dist#c.unity "Distance * Ambiguity * Unity" /*
		*/ 			  single_issue "Single Issue Party" government "Government Party" vote_share "Vote Share" partisan "Partisan Voter" educ "Education" 7.wave "2nd Wave" _cons "Constant")

	
	*### Table 3 ###*
	
	*# Set up the program including 1st and 2nd stage
	program myModel1

		*# First Stage Model
		xtmixed dist c.act_dist##c.ambiguityDum##c.unity single_issue government vote_share partisan educ i.wave || party: || party_wave:, technique(nr 15 dfp 5)
		predict dist_hat, xb
			
		*# Second Stage Model
		clogit vote_intention dist_hat, group(wave_individual) 
		drop dist_hat
	end

	*# obtain bootstrapped standard errors
	bootstrap, reps(1000): myModel1

	/* Conditional (fixed-effects) logistic regression

													Number of obs     =      5,133
													Replications      =      1,000
													Wald chi2(1)      =     232.02
													Prob > chi2       =     0.0000
	Log likelihood = -1243.7048                     Pseudo R2         =     0.2590
	
							(Replications based on clustering on wave_individual)
	--------------------------------------------------------------------------------
				   |   Observed   Bootstrap                         Normal-based
	vote_intention |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
	---------------+----------------------------------------------------------------
		dist_hat |   -.957617   .0628686   -15.23   0.000    -1.080837   -.8343968
	--------------------------------------------------------------------------------	*/

	

	*## Model 2
	*# Set up the program including 1st and 2nd stage
	program myModel2

	*# First Stage Model
	xtmixed dist c.act_dist##c.ambiguityDum##c.unity single_issue government vote_share partisan educ i.wave || party: || party_wave:
	predict dist_hat, xb
			
	*# Second Stage Model
	clogit vote_intention dist_hat single_issue government vote_share partisan, group(wave_individual)
	drop dist_hat
	end

	*# Obtain bootstrapped standard errors
	bootstrap, reps(1000): myModel2

	/*
	                                                Number of obs     =      5,133
													Replications      =      1,000
													Wald chi2(5)      =     349.87
													Prob > chi2       =     0.0000
	Log likelihood = -1004.3008                     Pseudo R2         =     0.4016

							   (Replications based on clustering on wave_individual)
	--------------------------------------------------------------------------------
				   |   Observed   Bootstrap                         Normal-based
	vote_intention |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
	---------------+----------------------------------------------------------------
		  dist_hat |    -.47513   .0585091    -8.12   0.000    -.5898056   -.3604543
	  single_issue |   .0603522   .1970131     0.31   0.759    -.3257863    .4464907
		government |  -.4811573   .1381173    -3.48   0.000    -.7518622   -.2104524
		vote_share |   .0438086   .0077992     5.62   0.000     .0285224    .0590948
		  partisan |   1.788982   .1607611    11.13   0.000     1.473896    2.104068
	--------------------------------------------------------------------------------  */

			
	*### Figure 2 ###*
	capture drop dist_hat
	xtmixed dist c.act_dist##i.ambiguityDum##c.unity single_issue government vote_share partisan educ i.wave || party: || party_wave:  
	predict dist_hat if e(sample), xb
	
	capture drop x* pred*
	
	gen xunity = .
	gen predV = .
	gen predVhi = .
	gen predVlw = .
	gen predC = .
	gen predChi = .
	gen predClw = .
	
	local a = 1
	forvalues i = 1/11 {
			
		replace xunity = `a' in `i'
		
		margins, at(unity = `i' ambiguityDum = 1 act_dist = 2.21) level(95)

		matrix A = r(table)
		matrix list A 
			
		replace predV 	= A[1, 1] in `i'
		replace predVlw = A[5, 1] in `i'
		replace predVhi = A[6, 1] in `i'
		
		margins, at(unity = `i' ambiguityDum = 0 act_dist = 2.21) level(95)

		matrix B = r(table)
		matrix list B 
			
		replace predC   = B[1, 1] in `i'
		replace predClw = B[5, 1] in `i'
		replace predChi = B[6, 1] in `i'
			
		local a = `a' + 1
	}
		
	sort xunity
	# delimit ;
	twoway (line predVlw xunity, lpattern(dash) lcolor(black))
		|| (line predVhi xunity, lpattern(dash) lcolor(black))
		|| (line predV xunity, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			yscale(off fill)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Perceived Party Unity")
			ytitle("Predicted Perceived Distance")
			title("High Ambiguity")
			name(vague_dist, replace);
	# delimit cr
	
	# delimit ;
	twoway (line predClw xunity, lpattern(dash) lcolor(black))
		|| (line predChi xunity, lpattern(dash) lcolor(black))
		|| (line predC xunity, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Perceived Party Unity")
			ytitle("Predicted Perceived Distance")
			title("Low Ambiguity")
			name(clear_dist, replace);
	# delimit cr

	gr combine clear_dist vague_dist, col(2) ycommon imargin(tiny)
	
	
	
	*### Figure 3 ###*
	
	*### (A) Run the 2nd stage model based on "dist_hat" derived from first model
	clogit vote_intention dist_hat, group(wave_individual)
	
	*### (B) Predict probabilities based on different distance estimates (derived from first model)
	gen pred_prMd_v = .
	gen pred_prLw_v = .
	gen pred_prHi_v = .
	gen pred_prMd_c = .
	gen pred_prLw_c = .
	gen pred_prHi_c = .	
		
	local a = 1
	forvalues i = 1/11 {
		
		local j = predV[`i']  // predV comes from Figure 2. 
		margins, at(dist_hat = `j') level(95)

		matrix C = r(table)
		matrix list C 
		
		replace pred_prMd_v = C[1, 1] in `i'
		replace pred_prLw_v = C[5, 1] in `i'
		replace pred_prHi_v = C[6, 1] in `i'
		
		local k = predC[`i']
		margins, at(dist_hat = `k') level(95)

		matrix D = r(table)
		matrix list D 
		
		replace pred_prMd_c = D[1, 1] in `i'
		replace pred_prLw_c = D[5, 1] in `i'
		replace pred_prHi_c = D[6, 1] in `i'
		
		local a = `a' + 1
	}
	
	
	sort xunity
	# delimit ;
	twoway (line pred_prLw_v xunity, lpattern(dash) lcolor(black))
		|| (line pred_prHi_v xunity, lpattern(dash) lcolor(black))
		|| (line pred_prMd_v xunity, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			yscale(off fill)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Perceived Party Unity")
			ytitle("Predicted Voting Probability")
			title("High Ambiguity")
			name(vague_vote, replace);
	# delimit cr
	
	# delimit ;
	twoway (line pred_prLw_c xunity, lpattern(dash) lcolor(black))
		|| (line pred_prHi_c xunity, lpattern(dash) lcolor(black))
		|| (line pred_prMd_c xunity, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Perceived Party Unity")
			ytitle("Predicted Voting Probability")
			title("Low Ambiguity")
			name(clear_vote, replace);
	# delimit cr
	
	gr combine clear_vote vague_vote, col(2) ycommon imargin(tiny)


		
*##==============================##
*## Appendix: Tables and Figures ##
*##==============================##

*### Appendix A: Replication of Somer-Topcu (2015)
	
	*### Table A1 ###*
	xtmixed dist c.act_dist##c.disagreement single_issue government vote_share partisan educ i.wave || party: || party_wave:
	
	
	*### Figure A1 ###*
	capture drop xaxis-predLw
	
	gen xaxis = .
	gen pred = .
	gen predHi = .
	gen predLw = .
	
	local a = 1
	forvalues i = 0(.03).3 {
			
		replace xaxis = `i' in `a'
		
		margins, dydx(act_dist) at(disagreement = `i') level(95)

		matrix A = r(table)
		matrix list A 
			
		replace pred 	= A[1, 1] in `a'
		replace predLw = A[5, 1] in `a'
		replace predHi = A[6, 1] in `a'
			
		local a = `a' + 1
	}
		
	set scheme sol
	# delimit ;
	twoway (line predLw xaxis, lpattern(dash) lcolor(black))
		|| (line predHi xaxis, lpattern(dash) lcolor(black))
		|| (line pred xaxis, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Party Ambiguity")
			ytitle("Marginal Effect")
			title("")
			name(zenep, replace);
	# delimit cr

		
		
*### Appendix B: Robustness Check by treating Ambiguity as a continuous variable 

	*### Table A2 ###*
	xtmixed dist c.act_dist##c.disagreement##c.unity || party: || party_wave:  
	est store m1 
	
	xtmixed dist c.act_dist##c.disagreement##c.unity single_issue government vote_share partisan educ i.wave || party: || party_wave:  
	est store m2
	
	esttab m1 m2, b(%10.3f) se scalars (N ll) star(+ 0.10 * 0.05 ** 0.01) noomitted /*
		*/ keep(act_dist disagreement unity c.act_dist#c.disagreement c.act_dist#c.unity c.disagreement#c.unity c.act_dist#c.disagreement#c.unity  /*
		*/		single_issue government vote_share partisan educ 7.wave _cons) /*
		*/ coeflabels(act_dist "Actual Distance" c.disagreement "Ambiguity" unity "Perceived Party Unity" c.act_dist#c.disagreement "Distance * Ambiguity" /*
		*/			  c.act_dist#c.unity "Distance * Unity" c.disagreement#c.unity "Ambiguity * Unity" c.act_dist#c.disagreement#c.unity "Distance * Ambiguity * Unity" /*
		*/ 			  single_issue "Single Issue Party" government "Government Party" vote_share "Vote Share" partisan "Partisan Voter" educ "Education" 7.wave "2nd Wave" _cons "Constant")
		
	*### Figure A2 ###*
	capture drop x* pred*
	
	gen xunity = .
	gen predV = .
	gen predVhi = .
	gen predVlw = .
	gen predC = .
	gen predChi = .
	gen predClw = .
	
	local a = 1
	forvalues i = 1/11 {
			
		replace xunity = `a' in `i'
		
		margins, dydx(act_dist) at(unity = `i' disagreement = 0.27) level(95)

		matrix A = r(table)
		matrix list A 
			
		replace predV 	= A[1, 1] in `i'
		replace predVlw = A[5, 1] in `i'
		replace predVhi = A[6, 1] in `i'
		
		margins, dydx(act_dist) at(unity = `i' disagreement = 0.09) level(95)

		matrix B = r(table)
		matrix list B 
			
		replace predC   = B[1, 1] in `i'
		replace predClw = B[5, 1] in `i'
		replace predChi = B[6, 1] in `i'
			
		local a = `a' + 1
	}
		
	sort xunity
	# delimit ;
	twoway (line predVlw xunity, lpattern(dash) lcolor(black))
		|| (line predVhi xunity, lpattern(dash) lcolor(black))
		|| (line predV xunity, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			yscale(off fill)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Perceived Party Unity")
			ytitle("Predicted Perceived Distance")
			title("High Ambiguity")
			name(vague_dist, replace);
	# delimit cr
	
	# delimit ;
	twoway (line predClw xunity, lpattern(dash) lcolor(black))
		|| (line predChi xunity, lpattern(dash) lcolor(black))
		|| (line predC xunity, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Perceived Party Unity")
			ytitle("Predicted Perceived Distance")
			title("Low Ambiguity")
			name(clear_dist, replace);
	# delimit cr

	gr combine clear_dist vague_dist, col(2) ycommon imargin(tiny)

	
	
*### Appendix C: Robustness Check by adding respondent fixed-effects 	
	
	*### Table A3 ###*
	xtmixed dist c.act_dist##i.ambiguityDum##c.unity single_issue government vote_share partisan educ i.wave i.id_g || party: || party_wave:  
	est store m3
		
		esttab m3, b(%10.3f) se scalars (N ll) star(+ 0.10 * 0.05 ** 0.01) noomitted /*
		*/ keep(act_dist disagreement unity c.act_dist#c.disagreement c.act_dist#c.unity c.disagreement#c.unity c.act_dist#c.disagreement#c.unity  /*
		*/		single_issue government vote_share partisan educ 7.wave _cons) /*
		*/ coeflabels(act_dist "Actual Distance" c.disagreement "Ambiguity" unity "Perceived Party Unity" c.act_dist#c.disagreement "Distance * Ambiguity" /*
		*/			  c.act_dist#c.unity "Distance * Unity" c.disagreement#c.unity "Ambiguity * Unity" c.act_dist#c.disagreement#c.unity "Distance * Ambiguity * Unity" /*
		*/ 			  single_issue "Single Issue Party" government "Government Party" vote_share "Vote Share" partisan "Partisan Voter" educ "Education" 7.wave "2nd Wave" _cons "Constant")
		
	
	*### Figure A3 ###*
	xtmixed dist c.act_dist##i.ambiguityDum##c.unity single_issue government vote_share partisan educ i.wave i.id_g || party: || party_wave:  
	predict dist_hat if e(sample), xb
	
	capture drop x* pred*
	
	gen xunity = .
	gen predV = .
	gen predVhi = .
	gen predVlw = .
	gen predC = .
	gen predChi = .
	gen predClw = .
	
	local a = 1
	forvalues i = 1/11 {
			
		replace xunity = `a' in `i'
		
		margins, at(unity = `i' ambiguityDum = 1 act_dist = 2.21) level(95)

		matrix A = r(table)
		matrix list A 
			
		replace predV 	= A[1, 1] in `i'
		replace predVlw = A[5, 1] in `i'
		replace predVhi = A[6, 1] in `i'
		
		margins, at(unity = `i' ambiguityDum = 0 act_dist = 2.21) level(95)

		matrix B = r(table)
		matrix list B 
			
		replace predC   = B[1, 1] in `i'
		replace predClw = B[5, 1] in `i'
		replace predChi = B[6, 1] in `i'
			
		local a = `a' + 1
	}
		
	sort xunity
	# delimit ;
	twoway (line predVlw xunity, lpattern(dash) lcolor(black))
		|| (line predVhi xunity, lpattern(dash) lcolor(black))
		|| (line predV xunity, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			yscale(off fill)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Perceived Party Unity")
			ytitle("Predicted Perceived Distance")
			title("High Ambiguity")
			name(vague_dist, replace);
	# delimit cr
	
	# delimit ;
	twoway (line predClw xunity, lpattern(dash) lcolor(black))
		|| (line predChi xunity, lpattern(dash) lcolor(black))
		|| (line predC xunity, lcolor(black)),		 
			t1("", size(small))
			legend(off)
			xlabel(, labsize(small))
			ylabel(, labsize(small))
			xtitle("Perceived Party Unity")
			ytitle("Predicted Perceived Distance")
			title("Low Ambiguity")
			name(clear_dist, replace);
	# delimit cr

	gr combine clear_dist vague_dist, col(2) ycommon imargin(tiny)
